using System;
using System.Drawing;
using System.Drawing.Imaging;

namespace Game
{
	/// <summary>
	/// Summary description for Resources.
	/// </summary>
	public class Resources
	{
		public static Random random = new Random();

		public Bitmap board_tiles;
		public Bitmap game_side;
		public Bitmap game_larea;
		public Bitmap icon_heart;

		public Bitmap[] board_items;
		public Bitmap[] player_sprites;
		public Bitmap[] turn_icons;

		public Font font_comic_big = new Font( "Comic Sans MS", 35 );
		public Font font_comic_medium = new Font( "Comic Sans MS", 20, FontStyle.Bold );
		public Font font_comic_small = new Font( "Comic Sans MS", 12, FontStyle.Bold );
		public Font font_comic_tiny = new Font( "Comic Sans MS", 10, FontStyle.Bold );

		private static String[] item_names =
		{
			"Data/item_ammo.png",
			"Data/item_missile.png",
			"Data/heart.png",
		};
		private static String[] player_names =
		{
			"Data/plr_left.png",
			"Data/plr_up.png",
			"Data/plr_right.png",
			"Data/plr_down.png",
		};
		private static String[] icon_names =
		{
			"Data/icon_left.png",
			"Data/icon_fwd.png",
			"Data/icon_right.png",
			"Data/icon_shoot.png",
			"Data/icon_missile.png",
			"Data/icon_pass.png",
		};

		public Resources( Graphics g )
		{
			board_tiles = new Bitmap( "Data/tiles.png" );
			game_side = new Bitmap( "Data/side.png" );
			game_larea = new Bitmap( "Data/larea.png" );
			icon_heart = new Bitmap( "Data/heart.png" );

			board_items = new Bitmap[ item_names.Length ];
			for ( int i = 0; i < item_names.Length; ++i )
			{
				board_items[ i ] = new Bitmap( item_names[ i ] );
			}

			player_sprites = new Bitmap[ player_names.Length ];
			for ( int i = 0; i < player_names.Length; ++i )
			{
				player_sprites[ i ] = new Bitmap( player_names[ i ] );
			}

			turn_icons = new Bitmap[ icon_names.Length ];
			for ( int i = 0; i < icon_names.Length; ++i )
			{
				turn_icons[ i ] = new Bitmap( icon_names[ i ] );
			}
		}

		public static void Write_Shade( Graphics g, Font f, String s, int x, int y )
		{
			int add = (int) f.Size / 6;
			if ( add <= 0 )
				add = 1;

			g.DrawString( s, f, Brushes.Black, x + add, y + add );
			g.DrawString( s, f, Brushes.White, x, y );
		}

		public static void Write_Center( Graphics g, Brush b, Font f, String s, int x, int y )
		{
			SizeF size = g.MeasureString( s, f );
			g.DrawString( s, f, b, x - ( size.Width / 2 ), y - ( size.Height / 2 ) );
		}

		public static void Write_Center_Shade( Graphics g, Font f, String s, int x, int y )
		{
			Write_Center_Shade( g, f, s, x, y, Color.White );
		}

		public static void Write_Center_Shade( Graphics g, Font f, String s, int x, int y, Color col )
		{
			int add = (int) f.Size / 6;
			if ( add <= 0 )
				add = 1;

			Brush b = new SolidBrush( col );
			Write_Center( g, Brushes.Black, f, s, x + add, y + add );
			Write_Center( g, b, f, s, x, y );
		}

		public static void Draw_Image( Graphics g, Bitmap b, int x, int y )
		{
			int w = b.Width;
			int h = b.Height;
			g.DrawImage( b, new Rectangle( x, y, w, h ), 0, 0, w, h, GraphicsUnit.Pixel );
		}

		public static void Draw_Image_Center( Graphics g, Bitmap b, int x, int y )
		{
			int w = b.Width;
			int h = b.Height;
			Draw_Image( g, b, x - w / 2, y - h / 2 );
		}
	}
}
